==> qiho-center-api-2.5.81-sources.jar: com/qiho/center/api/remoteservice/merchant/RemoteMerchantService.java <==
package com.qiho.center.api.remoteservice.merchant;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import com.qiho.center.api.dto.OpenInterfaceDto;
import com.qiho.center.api.dto.PagenationDto;
import com.qiho.center.api.dto.SimpleIdAndNameDto;
import com.qiho.center.api.dto.merchant.MerchantDto;
import com.qiho.center.api.dto.merchant.MerchantSimpleDto;
import com.qiho.center.api.dto.merchant.MerchantSpacialDto;
import com.qiho.center.api.enums.merchant.BaiqiMerchantLinkTypeEnum;
import com.qiho.center.api.params.MerchantQueryParams;
import com.qiho.center.api.params.OpenInterfaceQueryParams;

import java.util.List;

/**
 * 商家服务远程接口
 *
 * @author chensong
 * @create 2017-11-15 10:56
 **/
@AdvancedFeignClient
public interface RemoteMerchantService {

    /**
     * 根据id 获取商家信息
     *
     * @param merchantId
     * @return
     */
    MerchantDto findById(Long merchantId);

    /**
     * 创建或更新商家
     *
     * @param dto
     * @return
     */
    Boolean saveMerchant(MerchantDto dto) throws BizException;

    /**
     * 分页查询商家信息
     *
     * @param params
     * @return
     */
    PagenationDto<MerchantDto> querypage(MerchantQueryParams params);

    /**
     * 根据商家名称半模糊匹配
     *
     * @param name
     * @return
     */
    List<MerchantDto> findListByName(String name);

    /**
     * 根据商品Id返回商家信息
     *
     * @param itemId
     * @return
     */
    MerchantDto findByItemId(Long itemId);

    /**
     * 查询所有商家id和名称
     *
     * @return
     */
    List<SimpleIdAndNameDto> findAllMerchantSimple();

    /**
     * 查询所有排除已经关联过的商家庄户的商家的id和名称
     *
     * @return
     */
    List<SimpleIdAndNameDto> findAllIdAndNames();

    /**
     * 获取所有商家简单数据信息
     *
     * @return 集合
     */
    List<MerchantSpacialDto> findAll();

    /**
     * 根据所属aeId查询商家
     *
     * @param ownerAeId
     * @return
     */
    List<MerchantSpacialDto> findByOwnerAeId(Long ownerAeId);

    /**
     * 根据商家和类型查询广告主ID
     *
     * @param merchantId   商家ID
     * @param relationType 类型值
     * @param merchantId
     * @return
     */
    Long findRelationIdByMerchantIdAndRelationType(Long merchantId, BaiqiMerchantLinkTypeEnum relationType);

    /**
     * 查询商家不配送地区
     *
     * @param merchantId 商家id
     *
     * @return 商家不配送等行政区域代码集
     */
    List<String> findUndelivery(Long merchantId);

    /**
     * 分页查询已存在验证信息的商家信息
     *
     * @param params
     *
     * @return
     */
    PagenationDto<OpenInterfaceDto> openInterfacePageQuery(OpenInterfaceQueryParams params);

    /**
     * 保存对外开放商家验证信息
     *
     * @param dto
     *
     * @return
     */
    Boolean saveOpenInterface(OpenInterfaceDto dto);

    /**
     * 更新对外开放商家验证信息
     *
     * @param dto
     *
     * @return
     */
    Boolean updateOpenInterface(OpenInterfaceDto dto);

    /**
     * 根据商家id 获取对外接口信息
     *
     * @param merchantId
     *
     * @return
     */
    OpenInterfaceDto findByMerchantId(Long merchantId);

    /**
     * 根据appKey获取对外接口信息
     *
     * @param appKey
     *
     * @return
     */
    OpenInterfaceDto findByAppKey(String appKey);

    /**
     * 根据商家名称模糊查询
     *
     * @param merchantName
     *
     * @return
     */
    List<MerchantSimpleDto> findNoOpenInterface(String merchantName);

    /**
     * 初始化对外开放商家验证信息
     *
     * @param dto
     * @return
     */
    Boolean initOpenInterface(OpenInterfaceDto dto);

    /**
     * 查询已存在验证信息的商家总数
     */
    Integer findHasAppKeyCount();

    /**
     * 验证信息
     * @param appKey
     * @param appSecret
     * @return
     */
    OpenInterfaceDto checkedAppKey(String appKey, String appSecret);

    /**
     * 更新商家版本
     * @param versionSign
     * @param id
     * @return
     */
    boolean updateVersionSign(String versionSign,Long id);
}

==> qiho-center-api-2.9.6-20210525.064243-1-sources.jar: com/qiho/center/api/remoteservice/merchant/RemoteMerchantService.java <==
package com.qiho.center.api.remoteservice.merchant;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import com.qiho.center.api.dto.OpenInterfaceDto;
import com.qiho.center.api.dto.PagenationDto;
import com.qiho.center.api.dto.SimpleIdAndNameDto;
import com.qiho.center.api.dto.merchant.MerchantAddressDto;
import com.qiho.center.api.dto.merchant.MerchantDto;
import com.qiho.center.api.dto.merchant.MerchantSimpleDto;
import com.qiho.center.api.dto.merchant.MerchantSpacialDto;
import com.qiho.center.api.enums.merchant.BaiqiMerchantLinkTypeEnum;
import com.qiho.center.api.params.MerchantQueryParams;
import com.qiho.center.api.params.OpenInterfaceQueryParams;

import java.util.List;

/**
 * 商家服务远程接口
 *
 * @author chensong
 * @create 2017-11-15 10:56
 **/
@AdvancedFeignClient
public interface RemoteMerchantService {

    /**
     * 根据id 获取商家信息
     *
     * @param merchantId
     * @return
     */
    MerchantDto findById(Long merchantId);

    /**
     * 创建或更新商家
     *
     * @param dto
     * @return
     */
    Boolean saveMerchant(MerchantDto dto) throws BizException;

    /**
     * 分页查询商家信息
     *
     * @param params
     * @return
     */
    PagenationDto<MerchantDto> querypage(MerchantQueryParams params);

    /**
     * 根据商家名称半模糊匹配
     *
     * @param name
     * @return
     */
    List<MerchantDto> findListByName(String name);

    /**
     * 根据商品Id返回商家信息
     *
     * @param itemId
     * @return
     */
    MerchantDto findByItemId(Long itemId);

    /**
     * 查询所有商家id和名称
     *
     * @return
     */
    List<SimpleIdAndNameDto> findAllMerchantSimple();

    /**
     * 查询所有排除已经关联过的商家庄户的商家的id和名称
     *
     * @return
     */
    List<SimpleIdAndNameDto> findAllIdAndNames();

    /**
     * 获取所有商家简单数据信息
     *
     * @return 集合
     */
    List<MerchantSpacialDto> findAll();

    /**
     * 根据所属aeId查询商家
     *
     * @param ownerAeId
     * @return
     */
    List<MerchantSpacialDto> findByOwnerAeId(Long ownerAeId);

    /**
     * 根据商家和类型查询广告主ID
     *
     * @param merchantId   商家ID
     * @param relationType 类型值
     * @param merchantId
     * @return
     */
    Long findRelationIdByMerchantIdAndRelationType(Long merchantId, BaiqiMerchantLinkTypeEnum relationType);

    /**
     * 查询商家不配送地区
     *
     * @param merchantId 商家id
     *
     * @return 商家不配送等行政区域代码集
     */
    List<String> findUndelivery(Long merchantId);

    /**
     * 分页查询已存在验证信息的商家信息
     *
     * @param params
     *
     * @return
     */
    PagenationDto<OpenInterfaceDto> openInterfacePageQuery(OpenInterfaceQueryParams params);

    /**
     * 保存对外开放商家验证信息
     *
     * @param dto
     *
     * @return
     */
    Boolean saveOpenInterface(OpenInterfaceDto dto);

    /**
     * 更新对外开放商家验证信息
     *
     * @param dto
     *
     * @return
     */
    Boolean updateOpenInterface(OpenInterfaceDto dto);

    /**
     * 根据商家id 获取对外接口信息
     *
     * @param merchantId
     *
     * @return
     */
    OpenInterfaceDto findByMerchantId(Long merchantId);

    /**
     * 根据appKey获取对外接口信息
     *
     * @param appKey
     *
     * @return
     */
    OpenInterfaceDto findByAppKey(String appKey);

    /**
     * 根据商家名称模糊查询
     *
     * @param merchantName
     *
     * @return
     */
    List<MerchantSimpleDto> findNoOpenInterface(String merchantName);

    /**
     * 初始化对外开放商家验证信息
     *
     * @param dto
     * @return
     */
    Boolean initOpenInterface(OpenInterfaceDto dto);

    /**
     * 查询已存在验证信息的商家总数
     */
    Integer findHasAppKeyCount();

    /**
     * 验证信息
     * @param appKey
     * @param appSecret
     * @return
     */
    OpenInterfaceDto checkedAppKey(String appKey, String appSecret);

    /**
     * 更新商家版本
     * @param versionSign
     * @param id
     * @return
     */
    boolean updateVersionSign(String versionSign,Long id);

    /**
     * 查询所有商家的id和名称
     *
     * @return
     */
    List<MerchantSimpleDto> findIdAndNamesByIds(List<Long> ids);

    /**
     * 商家地址列表
     * @param merchantId 商家id
     * @return 商家地址列表
     */
    PagenationDto<MerchantAddressDto> getMerchantAddressList(Long merchantId) throws BizException;

    /**
     * 新增/修改商户地址
     * @param address 商户地址
     * @return 地址id
     */
    Long saveMerchantAddress(MerchantAddressDto address) throws BizException;

    /**
     * 删除商户地址
     * @param id id
     * @return 是否成功
     */
    Boolean deleteMerchantAddress(Long id) throws BizException;
}
